@@ -56,6 +56,7 @@
 #include "missingincludemodel.h"
 #include <templateparameterdeclaration.h>
 #include <language/duchain/classdeclaration.h>
+#include "qpropertydeclaration.h"
 
 // #define ifDebug(x) x
 
@@ -95,13 +96,6 @@ QStringList arithmeticComparisonOperators = QString("!= <= >= < >" ).split( ' ',
 
 QStringList allOperators = QString("++ + -- += -= *= /= %= ^= &= |= << >> >>= <<= == != <= >= && || [ - * / % & | = < >" ).split( ' ', QString::SkipEmptyParts );
 
-
-
-//Whether the list of argument-hints should contain all overloaded versions of operators.
-//Disabled for now, because there is usually a huge list of overloaded operators.
-const int maxOverloadedOperatorArgumentHints = 5;
-const int maxOverloadedArgumentHints = 20;
-
 //Whether identifiers starting with "__" or "_Uppercase" and that are not declared in the current file should be excluded from the code completion
 const bool excludeReservedIdentifiers = true;
 
@@ -217,22 +211,22 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
 
   m_valid = isValidPosition();
   if( !m_valid ) {
-    log( "position not valid for code-completion" );
+    kDebug() << "position not valid for code-completion";
     return;
   }
 
-  ifDebug( log( "non-processed text: " + m_text ); )
+  ifDebug( kDebug() << "non-processed text: " + m_text; )
   if(depth == 0) {
     preprocessText( line );
     m_text = clearComments( m_text );
   }
     
-  ifDebug( log( "preprocessed text: " + m_text ); )
+  ifDebug( kDebug() << "preprocessed text: " + m_text; )
 
    m_text = stripFinalWhitespace( m_text );
    m_text = lastLines(m_text);
 
-  ifDebug( log( QString("depth %1").arg(depth) + " end of processed text: " + m_text ); )
+  ifDebug( kDebug() << QString("depth %1").arg(depth) + " end of processed text: " + m_text; )
 
   if(doConstructorCompletion())
     return;
@@ -343,7 +337,7 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
   int start_expr = Utils::expressionAt( m_text, m_text.length() );
 
   m_expression = m_text.mid(start_expr).trimmed();
-  ifDebug( log( "expression: " + m_expression ); )
+  ifDebug( kDebug() << "expression: " + m_expression; )
 
   if(m_expression == "else")
     m_expression = QString();
@@ -368,7 +362,7 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
 
   QString expressionPrefix = stripFinalWhitespace( m_text.left(start_expr) );
 
-  ifDebug( log( "expressionPrefix: " + expressionPrefix ); )
+  ifDebug( kDebug() << "expressionPrefix: " + expressionPrefix; )
 
   ///Handle constructions like "ClassType instance("
   if(!expressionPrefix.isEmpty() && (expressionPrefix.endsWith('>') || expressionPrefix[expressionPrefix.length()-1].isLetterOrNumber() || expressionPrefix[expressionPrefix.length()-1] == '_')) {
@@ -403,8 +397,8 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
     //Prevent useless endless recursion
     if(depth == 0 || parentContextText != m_text)
     {
-      log( QString("Recursive function-call: Searching parent-context in \"%1\"").arg(expressionPrefix) );
-      log( QString("This argument-number: %1 Building parent-context from \"%2\"").arg(otherArguments.size()).arg(parentContextText) );
+      kDebug() << QString("Recursive function-call: Searching parent-context in \"%1\"").arg(expressionPrefix);
+      kDebug() << QString("This argument-number: %1 Building parent-context from \"%2\"").arg(otherArguments.size()).arg(parentContextText);
       m_parentContext = new CodeCompletionContext( m_duContext, parentContextText, QString(), m_position, depth+1, otherArguments );
     }else{
       ifDebug( kDebug() << "not following at depth" << depth << " because:" << parentContextText << "==" << m_text; )
@@ -484,7 +478,7 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
   ///Handle overridden binary operator-functions
   if( endsWithOperator(expressionPrefix) || expressionPrefix.endsWith("return") ) {
     if(depth == 0 || m_text != expressionPrefix) {
-      log( QString( "Recursive operator: creating parent-context with \"%1\"" ).arg(expressionPrefix) );
+      kDebug() << QString( "Recursive operator: creating parent-context with \"%1\"" ).arg(expressionPrefix);
       m_parentContext = new CodeCompletionContext( m_duContext, expressionPrefix, QString(), m_position, depth+1 );
     }else{
       ifDebug( kDebug() << "not following operator at depth" << depth << " because:" << expressionPrefix  << "==" << m_text; )
@@ -554,7 +548,7 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
     ifDebug( kDebug(9007) << "expression result: " << m_expressionResult.toString(); )
     if( !m_expressionResult.isValid() ) {
       if( m_memberAccessOperation != StaticMemberChoose ) {
-        log( QString("expression \"%1\" could not be evaluated").arg(expr) );
+        kDebug() << QString("expression \"%1\" could not be evaluated").arg(expr);
         if(m_memberAccessOperation == FunctionCallAccess || m_memberAccessOperation == TemplateAccess)
           m_functionName = m_expression; //Keep the context valid, so missing-include completion can happen
         else
@@ -627,18 +621,18 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
                 m_expressionResult.type = function->returnType()->indexed();
                 m_expressionResult.isInstance = true;
               } else {
-                  log( QString("arrow-operator of class is not a function, or is non-const where the object being accessed is const: %1").arg(containerType ? containerType->toString() : QString("null") ) );
+                  kDebug() << QString("arrow-operator of class is not a function, or is non-const where the object being accessed is const: %1").arg(containerType ? containerType->toString() : QString("null") );
               }
             } else {
-              log( QString("arrow-operator on type without operator-> member: %1").arg(containerType ? containerType->toString() : QString("null") ) );
+              kDebug() << QString("arrow-operator on type without operator-> member: %1").arg(containerType ? containerType->toString() : QString("null") );
               if(idDecl->internalContext()->type() == DUContext::Class)
                 replaceCurrentAccess("->", ".");
             }
           } else {
-            log( QString("arrow-operator on type without declaration and context: %1").arg(containerType ? containerType->toString() : QString("null") ) );
+            kDebug() << QString("arrow-operator on type without declaration and context: %1").arg(containerType ? containerType->toString() : QString("null") );
           }
         } else {
-          log( QString("arrow-operator on invalid type: %1").arg(containerType ? containerType->toString() : QString("null") ) );
+          kDebug() << QString("arrow-operator on invalid type: %1").arg(containerType ? containerType->toString() : QString("null") );
           m_expressionResult = ExpressionEvaluationResult();
         }
       }
@@ -654,7 +648,7 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
     case MemberAccess:
     {
       if( expr.trimmed().isEmpty() ) {
-        log( "Expression was empty, cannot complete" );
+        kDebug() << "Expression was empty, cannot complete";
         m_valid = false;
       }
 
@@ -676,7 +670,7 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
         if(type.cast<PointerType>())
           replaceCurrentAccess(".", "->");
       }else{
-        log( "No type for expression" );
+        kDebug() << "No type for expression";
       }
     }
     break;
@@ -829,7 +823,7 @@ void CodeCompletionContext::processFunctionCallAccess() {
   if( m_contextType == BinaryOperatorFunctionCall ) {
 
     if( !m_expressionResult.isInstance ) {
-      log( "tried to apply an operator to a non-instance: " + m_expressionResult.toString() );
+      kDebug() << "tried to apply an operator to a non-instance: " + m_expressionResult.toString();
       m_valid = false;
       return;
     }
@@ -870,7 +864,7 @@ void CodeCompletionContext::processFunctionCallAccess() {
   }
   
 //   if( declarations.isEmpty() ) {
-//     log( QString("no list of function-declarations was computed for expression \"%1\"").arg(m_expression) );
+//     kDebug() << QString("no list of function-declarations was computed for expression \"%1\"").arg(m_expression);
 //     return;
 //   }
 }
@@ -1210,6 +1204,13 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& sh
                     continue;
                   else if(!filterDeclaration(decl.first, ctx))
                     continue;
+
+                  if (memberAccessOperation() == MemberAccess || memberAccessOperation() == ArrowMemberAccess) {
+                    // Don't allow constructors to be accessed with . or ->
+                    if (ClassFunctionDeclaration* classFun = dynamic_cast<ClassFunctionDeclaration*>(classMember))
+                      if (classFun->isConstructor())
+                       continue;
+                  }
                   
                   if(decl.first->kind() == Declaration::Namespace) {
                     QualifiedIdentifier id = decl.first->qualifiedIdentifier();
@@ -1275,19 +1276,23 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& sh
           {
             ifDebug( kDebug() << "functionCallAccess" << functions().count() << m_expression; )
             
+            uint max = MoreArgumentHintsCompletionItem::resetMaxArgumentHints();
+            
             //Don't show annoying empty argument-hints
 /*            if(parentContext->m_contextType != BinaryOperatorFunctionCall && parentContext->functions().size() == 0)
               break;*/
-            //When there is too many overloaded functions, do not show them. They can just be too many.
-            if (functions().count() > maxOverloadedOperatorArgumentHints) {
-              items << CompletionTreeItemPointer( new NormalDeclarationCompletionItem( KDevelop::DeclarationPointer(),  KSharedPtr <KDevelop::CodeCompletionContext >(this), 0, 0 ) );
-              if(functions().count())
-                items.back()->asItem<NormalDeclarationCompletionItem>()->alternativeText = i18ncp("Here, overload is used as a programming term.  This string is used to display how many overloaded versions there are of the function whose name is the second argument.  The numeric argument is always greater than one, so translation of the singular case is only necessary in languages where the singular form is used for 21, 31 etc.", "1 overload of %2", "%1 overloads of %2", functions().count(), functionName());
-            }else if(functions().count() == 0 && additionalContextType() != Cpp::CodeCompletionContext::BinaryOperatorFunctionCall) {
+            if(functions().count() == 0 && additionalContextType() != Cpp::CodeCompletionContext::BinaryOperatorFunctionCall) {
               items += missingIncludeCompletionItems(m_expression, QString(), m_expressionResult, m_duContext.data(), depth(), true );
             }else if(!functions().isEmpty()) {
               int num = 0;
               foreach( const Cpp::CodeCompletionContext::Function &function, functions() ) {
+                if (num == max) {
+                  //When there are too many overloaded functions, do not show them all if completion was invoked automatically
+                  CompletionTreeItemPointer item( new MoreArgumentHintsCompletionItem( KSharedPtr <KDevelop::CodeCompletionContext >(this), i18ncp("Here, overload is used as a programming term.  This string is used to display how many overloaded versions there are of the function whose name is the second argument.", "1 more overload of %2 (show more)", "%1 more overloads of %2 (show more)", functions().count() - num, functionName()), num ) );
+                  items << item;
+                  break;
+                }
+
                 items << CompletionTreeItemPointer( new NormalDeclarationCompletionItem( function.function.declaration(), KSharedPtr <KDevelop::CodeCompletionContext >(this), 0, num ) );
                 ++num;
               }
@@ -1603,14 +1608,14 @@ void CodeCompletionContext::standardAccessCompletionItems(QList<CompletionTreeIt
   QList<DeclarationDepthPair> decls = m_duContext->allDeclarations(m_duContext->type() == DUContext::Class ? m_duContext->range().end : m_position, m_duContext->topContext());
 
   //Collect the contents of unnamed namespaces
-  QList<Declaration*> unnamed = m_duContext->findDeclarations(QualifiedIdentifier(unnamedNamespaceIdentifier.identifier()), m_position);
+  QList<Declaration*> unnamed = m_duContext->findDeclarations(QualifiedIdentifier(unnamedNamespaceIdentifier().identifier()), m_position);
   foreach(Declaration* ns, unnamed)
     if(ns->kind() == Declaration::Namespace && ns->internalContext())
       decls += ns->internalContext()->allDeclarations(m_position, m_duContext->topContext(), false);
 
   if(m_duContext) {
     //Collect the Declarations from all "using namespace" imported contexts
-    QList<Declaration*> imports = m_duContext->findDeclarations( globalImportIdentifier, m_position, 0, DUContext::NoFiltering );
+    QList<Declaration*> imports = m_duContext->findDeclarations( globalImportIdentifier(), m_position, 0, DUContext::NoFiltering );
 
     QSet<QualifiedIdentifier> ids;
     foreach(Declaration* importDecl, imports) {
@@ -1743,7 +1748,7 @@ bool  CodeCompletionContext::filterDeclaration(Declaration* decl, DUContext* dec
   if(decl->indexedIdentifier().isEmpty()) //Filter out nameless declarations
     return false;
   
-  if(decl->indexedIdentifier() == friendIdentifier || decl->indexedIdentifier() == Cpp::unnamedNamespaceIdentifier)
+  if(decl->indexedIdentifier() == friendIdentifier || decl->indexedIdentifier() == Cpp::unnamedNamespaceIdentifier())
     return false;
   
   if(excludeReservedIdentifiers)
@@ -1785,7 +1790,7 @@ bool  CodeCompletionContext::filterDeclaration(Declaration* decl, DUContext* dec
     if(classMember)
       return filterDeclaration(classMember, declarationContext, typeIsConst);
   }
-  
+
   return true;
 }
 
@@ -1796,6 +1801,10 @@ bool  CodeCompletionContext::filterDeclaration(ClassMemberDeclaration* decl, DUC
     if(!Cpp::isAccessible(m_localClass ? m_localClass.data() : m_duContext.data(), decl, m_duContext->topContext(), declarationContext))
       return false;
   }
+  // filter properties from code completion, they mostly have to be accessed via their getter/setters
+  if (QPropertyDeclaration* property = dynamic_cast<QPropertyDeclaration*>(decl)) {
+    return false;
+  }
   return filterDeclaration((Declaration*)decl, declarationContext, false);
 }
 
