@@ -92,6 +92,7 @@ private slots:
   void testIntegralTemplates();
   void testTypedef();
   void testTypedefUnsignedInt();
+  void testTypedefFuncptr();
   void testTemplateDependentClass();
   void testTemplateFunctions();
   void testTypedefUses();
@@ -150,6 +151,7 @@ private slots:
   void testCodeModel();
   void testLoopNamespaceImport();
   void testConstructorUses();
+  void testExternalMemberDeclaration();
 
   void testSymbolTableValid();
   
