@@ -212,7 +212,7 @@ Cpp::ReferenceCountedMacroSet setupStandardMacros()
       m.formalsList().append(IndexedString("d"));
       m.formalsList().append(IndexedString("sig"));
       m.function_like = true;
-      m.setDefinitionText( "private slots: sig; private:" );
+      m.setDefinitionText( "private slots: sig{ d; }; private:" );
       insertMacro( macros, m );
       
       m.name = IndexedString("slots");
@@ -240,6 +240,21 @@ Cpp::ReferenceCountedMacroSet setupStandardMacros()
       m.setDefinitionText("__qt_slot__");
       m.formalsList().clear();
       insertMacro( macros, m );
+
+      m.name = IndexedString("Q_PROPERTY");
+      m.setDefinitionText("__qt_property__");
+      m.formalsList().clear();
+      insertMacro( macros, m );
+    }
+    
+    {
+      // We don't provide a real implementation of offsetof, but at least provide a stub that allows correct use-building for the member.
+      rpp::pp_macro m("__builtin_offsetof");
+      m.function_like = true;
+      m.formalsList().append(IndexedString("TYPE"));
+      m.formalsList().append(IndexedString("MEMBER"));
+      m.setDefinitionText("(size_t)((void)TYPE::MEMBER)");
+      insertMacro( macros, m );
     }
     
     foreach(const rpp::pp_macro* macro, gccStandardMacros())
