@@ -70,7 +70,6 @@
 #include "cmakeutils.h"
 #include "cmaketypes.h"
 #include "parser/cmakeparserutils.h"
-#include "icmakebuilder.h"
 #include "icmakedocumentation.h"
 
 #ifdef CMAKEDEBUGVISITOR
@@ -90,6 +89,7 @@
 #include <interfaces/iruncontroller.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
 #include <vcs/vcsjob.h>
+#include <project/interfaces/iprojectbuilder.h>
 
 using namespace KDevelop;
 
@@ -170,16 +170,13 @@ KUrl CMakeManager::buildDirectory(KDevelop::ProjectBaseItem *item) const
     KUrl ret;
     if(item) {
         bool isroot = false;
-        if (ProjectFolderItem* projectFolderItem = dynamic_cast<ProjectFolderItem*>(item)) {
-            if(!projectFolderItem->parent()) {
-                isroot = true;
-            }
-        }
+        if (ProjectFolderItem* projectFolderItem = item->folder())
+            isroot = !projectFolderItem->parent();
+        
         if (isroot) {
             ret=CMake::currentBuildDir(item->project());
-        }
-        else {
-            ret=buildDirectory(dynamic_cast<CMakeFolderItem*>(item->parent()));
+        } else {
+            ret=buildDirectory(item->parent());
             CMakeFolderItem *fi=dynamic_cast<CMakeFolderItem*>(item);
             if(fi)
                 ret.addPath(fi->buildDir());
@@ -353,8 +350,6 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
     m_watchers[item->project()]->addDir(item->url().toLocalFile());
     if(folder && folder->type()==KDevelop::ProjectBaseItem::BuildFolder)
     {
-        reloadFiles(folder);
-        
         kDebug(9042) << "parse:" << folder->url();
         KUrl cmakeListsPath(folder->url());
         cmakeListsPath.addPath("CMakeLists.txt");
@@ -457,7 +452,7 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
                 path.adjustPath(KUrl::AddTrailingSlash);
 
                 kDebug(9042) << "Found subdir " << path << "which should be into" << subroot;
-                if(subroot.isParentOf(path) || path.isParentOf(subroot))
+                if((subroot.isParentOf(path) || path.isParentOf(subroot)) && QFileInfo(path.toLocalFile()).isDir())
                 {
                     alreadyAdded.append(subf.name);
                     CMakeFolderItem* parent=folder;
@@ -588,6 +583,7 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
                 
                 setTargetFiles(targetItem, tfiles);
             }
+            reloadFiles(folder);
         }
     }
 
@@ -664,9 +660,9 @@ QHash< QString, QString > CMakeManager::defines(KDevelop::ProjectBaseItem *item
 
 KDevelop::IProjectBuilder * CMakeManager::builder(KDevelop::ProjectFolderItem *) const
 {
-    IPlugin* i = core()->pluginController()->pluginForExtension( "org.kdevelop.ICMakeBuilder" );
+    IPlugin* i = core()->pluginController()->pluginForExtension( "org.kdevelop.IProjectBuilder", "KDevCMakeBuilder");
     Q_ASSERT(i);
-    ICMakeBuilder* _builder = i->extension<ICMakeBuilder>();
+    KDevelop::IProjectBuilder* _builder = i->extension<KDevelop::IProjectBuilder>();
     Q_ASSERT(_builder );
     return _builder ;
 }
@@ -705,6 +701,9 @@ KDevelop::IProjectBuilder * CMakeManager::builder(KDevelop::ProjectFolderItem *)
 
 bool CMakeManager::reload(KDevelop::ProjectFolderItem* folder)
 {
+    if(isReloading(folder->project()))
+        return false;
+    
     CMakeFolderItem* item=dynamic_cast<CMakeFolderItem*>(folder);
     if ( !item ) {
         ProjectBaseItem* it = folder;
@@ -720,8 +719,6 @@ bool CMakeManager::reload(KDevelop::ProjectFolderItem* folder)
 
 void CMakeManager::reimport(KDevelop::ProjectFolderItem* fi)
 {
-    Q_ASSERT(!isReloading(fi->project()));
-    
     KJob *job=createImportJob(fi);
     job->setProperty("projectitem", qVariantFromValue(fi));
     
@@ -1152,10 +1149,6 @@ bool followUses(KTextEditor::Document* doc, SimpleRange r, const QString& name,
 
 bool CMakeManager::removeFile( KDevelop::ProjectFileItem* it)
 {
-    if ( !KDevelop::removeUrl(it->project(), it->url(), false) ) {
-        return false;
-    }
-
     bool ret=true;
     QList<ProjectFileItem*> files=it->project()->filesForUrl(it->url());
     QMap<ProjectTargetItem*, ProjectFileItem*> targets;
@@ -1163,24 +1156,16 @@ bool CMakeManager::removeFile( KDevelop::ProjectFileItem* it)
     //We loop through all the files with the same url
     foreach(ProjectFileItem* file, files)
     {
-        ProjectTargetItem* target=static_cast<ProjectBaseItem*>(file->parent())->target();
-        if(target) {
+        ProjectTargetItem* target=file->parent()->target();
+        if(target)
             targets.insert(target, file);
-        } else
-            file->parent()->removeRow(file->row());
     }
-
-    //only remove after we iterated over all files, otherwise the items
-    //might get deleted due to cmake files gettin reparsed
-    //TODO: this still leads to crashes if more than one item in a single target gets removed.
+    
     QMap< ProjectTargetItem*, ProjectFileItem* >::const_iterator it2 = targets.constBegin();
-    while (it2 != targets.constEnd()) {
-        bool res = removeFileFromTarget(it2.value(), it2.key());
-        ret = ret && res;
-        ++it2;
-    }
+    for(; it2!=targets.constEnd(); ++it2)
+        ret = ret && removeFileFromTarget(it2.value(), it2.key());
 
-    return ret;
+    return ret && KDevelop::removeUrl(it->project(), it->url(), false);
 }
 
 bool CMakeManager::removeFileFromTarget( KDevelop::ProjectFileItem* it, KDevelop::ProjectTargetItem* target)
@@ -1203,13 +1188,8 @@ bool CMakeManager::removeFileFromTarget( KDevelop::ProjectFileItem* it, KDevelop
     e.addDocuments(IndexedString(lists));
 
     bool ret=followUses(e.document(), r, ' '+it->text(), lists, false, QString());
-    if(ret)
-    {
-        if(e.exec())
-        {
-            e.applyAllChanges();
-        }
-    }
+    ret &= e.exec();
+    ret &= e.applyAllChanges();
     
     return ret;
 }
